package com.isa.jump.plugin;


import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Paint;
import java.awt.Stroke;
import java.awt.geom.NoninvertibleTransformException;
import java.util.List;

import org.openjump.util.SLDImporter.StrokeFillStyle;

import com.vividsolutions.jts.geom.Point;
import com.vividsolutions.jts.util.Assert;
import com.vividsolutions.jump.I18N;
import com.vividsolutions.jump.feature.Feature;
import com.vividsolutions.jump.util.StringUtil;
import com.vividsolutions.jump.workbench.model.Layer;
import com.vividsolutions.jump.workbench.ui.GUIUtil;
import com.vividsolutions.jump.workbench.ui.Viewport;
import com.vividsolutions.jump.workbench.ui.renderer.style.BasicFillPattern;
import com.vividsolutions.jump.workbench.ui.renderer.style.BasicStyle;
import com.vividsolutions.jump.workbench.ui.renderer.style.Style;
import com.vividsolutions.jump.workbench.ui.renderer.style.StyleUtil;

public class BaseStyleRGB extends BasicStyle implements Style, StrokeFillStyle {
	public static final String RGB_ATTRIBUTE_NAME = "R_G_B";
	private Color fillColor = DEFAULT_FILL_COLOR;
    private Color lineColor = DEFAULT_LINE_COLOR;
    private boolean renderingVertices = true;
////////////////////////////////////////////////////////// 
    public boolean getRenderingVertices() {
        return renderingVertices;
    }

    public void setRenderingVertices(boolean renderingVertices) {
        this.renderingVertices = renderingVertices;
    }
    public void paint(Feature f, Graphics2D g, Viewport viewport)
    throws NoninvertibleTransformException {
	Color fillColor = this.fillColor;
	Color lineColor = this.lineColor;
	Color featureColor = getFeatureColor(f);
	
	if (featureColor != null)
	{
		fillColor = featureColor;
		lineColor = featureColor.darker();
	}
    
	if (!renderingVertices && f.getGeometry() instanceof Point) {
        return;
    }
    }
	
	 /**
     * Looks for an Attriubte field that contains the RGB color code and returns
     * it or null if the RGB hex string is empty or ill-formed. 
     * @param    f   the <code>Feature</code> containing the RGB 
     * 			Attribute to be parsed.
     * @return   the <code>Color</code> represented by the R_B_G hex value with 
     *           the current Alpha value inserted.
     *           Warning: returns null in many "normal" cases.
     */
     public Color getFeatureColor(Feature f)
     {
      	if(f.getSchema().hasAttribute(RGB_ATTRIBUTE_NAME))
     	{
     		String colorStr = (String)f.getAttribute(RGB_ATTRIBUTE_NAME);
     		
     		if ((colorStr != null) && (colorStr.trim().length() == 6))
     		{
     			try
     			{
     				int r = Integer.parseInt(colorStr.substring(0,2), 16);
     				int g = Integer.parseInt(colorStr.substring(2,4), 16);
     				int b = Integer.parseInt(colorStr.substring(4,6), 16);
     				return new Color(r, g, b, getAlpha());
     			}
     			catch (NumberFormatException ex)
     			{
     				return null;
     			}
     		}
     	}
     	
     	return null;
     }
 }


