package com.isa.jump.plugin;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Color;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import javax.swing.*;

/*
 * JButton object based on JButton that draws a scaled Arrow pointing down.
 * It's designed for uses were an action is to be executed when the left half of
 * the button is clicked and brings up a panel when the right half of the button
 * is clicked.
 * <p>
 * <strong>Warning:</strong>
 * Serialized objects of this class will not be compatible with 
 * future Swing releases.  The current serialization support is appropriate
 * for short term storage or RMI between applications running the same
 * version of Swing.  A future release of Swing will provide support for
 * long term persistence.
 *
 * This class is based on javax.swing.plaf.basic.BasicArrowButton (version 1.17 08/28/98)
 */
 
public class ComboButton extends JButton
{
	static final int TRIANGLE = 0;
	static final int RECTANGLE = 1;
	
	private Color color = null;
	private int symbol = TRIANGLE;
	
    public ComboButton(int symbol)            
    {
    	super();
    	if (symbol >= TRIANGLE && symbol <= RECTANGLE)
    		this.symbol = symbol;
    	setRequestFocusEnabled(false);
        setBackground(UIManager.getColor("control"));
    }

    public void setColor(Color color)
    {
    	this.color = color;
    	repaint();
    }
    
    public Color getColor()
    {
    	return color;
    }
    
	public void paint(Graphics g) 
	{
	    Color origColor;
	    boolean isPressed, isEnabled;
	    int w, h, size;

        w = getSize().width;
        h = getSize().height;
	    origColor = g.getColor();
	    isPressed = getModel().isPressed();
	    isEnabled = isEnabled();

//        g.setColor(getBackground());
//        g.fillRect(1, 1, w-2, h-2);

        /// Draw the proper Border
//        if (isPressed) 
//        {
//            g.setColor(UIManager.getColor("controlShadow"));
//            g.drawRect(0, 0, w-1, h-1);
//        } 
//        else 
//        {
//            // Using the background color set above
//            g.drawLine(0, 0, 0, h-1);
//            g.drawLine(1, 0, w-2, 0);
//
//            g.setColor(UIManager.getColor("controlLtHighlight"));    // inner 3D border
//            g.drawLine(1, 1, 1, h-3);
//            g.drawLine(2, 1, w-3, 1);
//
//            g.setColor(UIManager.getColor("controlShadow"));       // inner 3D border
//            g.drawLine(1, h-2, w-2, h-2);
//            g.drawLine(w-2, 1, w-2, h-3);
//
//            g.setColor(UIManager.getColor("controlDkShadow"));     // black drop shadow  __|
//            g.drawLine(0, h-1, w-1, h-1);
//            g.drawLine(w-1, h-1, w-1, 0);
//        }

        // If there's no room to draw arrow, bail
        if(h < 5 || w < 5)      
        {
            g.setColor(origColor);
            return;
        }

        if (isPressed) 
        {
            g.translate(1, 1);
        }

        super.paint(g);
        // Draw the arrow
        size = Math.min((h - 4) / 3, (w - 4) / 3);
        size = Math.max(size, 2);
        if (symbol == TRIANGLE)
        	paintTriangle(g, ((w - size) / 2), (h - size) / 2, size, isEnabled);
        else
        	paintRectangle(g, ((w - size) / 2), (h - size) / 2, size, isEnabled);

        // Reset the Graphics back to its original settings
        if (isPressed) 
        {
            g.translate(-1, -1);
        }
        
	    g.setColor(origColor);
    }

    public Dimension getPreferredSize() 
    {
        return new Dimension(25, 25);
    }

    public Dimension getMinimumSize() 
    {
        return new Dimension(25, 25);
    }

    public Dimension getMaximumSize() 
    {
        return new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE);
    }
    
    public boolean isFocusTraversable() 
    {
    	return false;
	}

	private void paintTriangle(Graphics g, int x, int y, int size, boolean isEnabled) 
	{
		Color oldColor = g.getColor();
		int mid, i, j;
		j = 0;
		size = Math.max(size, 2);
		mid = size / 2;
		g.translate(x, y);
		
		if(isEnabled)
			g.setColor(UIManager.getColor("controlDkShadow"));
		else
			g.setColor(UIManager.getColor("controlShadow"));
		
        if(!isEnabled)  
        {
            g.translate(1, 1);
            g.setColor(UIManager.getColor("controlLtHighlight"));
            
            for(i = size-1; i >= 0; i--)   
            {
                g.drawLine(mid-i, j, mid+i, j);
                j++;
            }
            
            g.translate(-1, -1);
            g.setColor(UIManager.getColor("controlShadow"));
        }
        
		j = 0;
		
        for(i = size-1; i >= 0; i--)   
        {
            g.drawLine(mid-i, j, mid+i, j);
            j++;
        }
	    
	    g.translate(-x, -y);	
	    g.setColor(oldColor);
	}

	private void paintRectangle(Graphics g, int x, int y, int size, boolean isEnabled) 
	{
		Color oldColor = g.getColor();
		int i, j;
		j = 0;
		size = Math.max(size, 2);
		g.translate(x, y);
		
		if(isEnabled)
			if (color == null)
				g.setColor(new Color(0,0,0));
			else
				g.setColor(color);
		else
			g.setColor(UIManager.getColor("controlShadow"));
		
        if(!isEnabled)  
        {
            g.translate(1, 1);
            g.setColor(UIManager.getColor("controlLtHighlight"));
            
    		if (color == null) //draw an L
    		{
    			g.drawLine(0, 7, 5, 7);
    			g.drawLine(5, 7, 5, 6);
    			g.drawLine(1, 7, 1, 0);
    			g.drawLine(0, 0, 2, 0);
    		}
    		else
    		{
    	        for(i = size-1; i >= 0; i--)   
    	        {
    	            g.drawLine(0, j, 7, j);
    	            j++;
    	        }
    		}
            
            g.translate(-1, -1);
            g.setColor(UIManager.getColor("controlShadow"));
        }
        
		j = 0;
		
		if (color == null) //draw an L
		{
			g.drawLine(0, 7, 5, 7);
			g.drawLine(5, 7, 5, 6);
			g.drawLine(1, 7, 1, 0);
			g.drawLine(0, 0, 2, 0);
		}
		else
		{
	        for(i = size-1; i >= 0; i--)   
	        {
	            g.drawLine(0, j, 7, j);
	            j++;
	        }
		}
	    
	    g.translate(-x, -y);	
	    g.setColor(oldColor);
	}
}

